==> symfony_5.4.23+dfsg.orig.tar.xz: symfony-5.4.23/src/Symfony/Component/Intl/Resources/data/scripts/mi.php <==
<?php

return [
    'Names' => [
        'Adlm' => 'Arāma',
        'Arab' => 'Arapika',
        'Aran' => 'Natārika',
        'Armn' => 'Āmeiniana',
        'Beng' => 'Pāngara',
        'Bopo' => 'Papamawha',
        'Brai' => 'Tuhi Matapō',
        'Cakm' => 'Tiakamā',
        'Cans' => 'Ngā Tohu o te reo o ngā iwi Taketake o Kānata kua paiheretia',
        'Cher' => 'Terokī',
        'Cyrl' => 'Hīririki',
        'Deva' => 'Tewhangāngari',
        'Ethi' => 'Etiopika',
        'Geor' => 'Hōriana',
        'Grek' => 'Kiriki',
        'Gujr' => 'Kutarāti',
        'Guru' => 'Kūmuki',
        'Hanb' => 'Hana me te Papamawha',
        'Hang' => 'Hāngū',
        'Hani' => 'Hana',
        'Hans' => 'Māmā',
        'Hant' => 'Tuku iho',
        'Hebr' => 'Hīperu',
        'Hira' => 'Hirakana',
        'Hrkt' => 'Tohu Hapanihi',
        'Jamo' => 'Hamo',
        'Jpan' => 'Hapanihi',
        'Kana' => 'Katakana',
        'Khmr' => 'Kimei',
        'Knda' => 'Kanara',
        'Kore' => 'Kōreana',
        'Laoo' => 'Rao',
        'Latn' => 'Rātina',
        'Mlym' => 'Maramara',
        'Mong' => 'Mongōriana',
        'Mtei' => 'Meitei Maeke',
        'Mymr' => 'Mienemā',
        'Nkoo' => 'Unukō',
        'Olck' => 'Ōtiki',
        'Orya' => 'Otia',
        'Rohg' => 'Hāniwhi',
        'Sinh' => 'Hināra',
        'Sund' => 'Hunanihi',
        'Syrc' => 'Hīriaka',
        'Taml' => 'Tamiera',
        'Telu' => 'Teruku',
        'Tfng' => 'Tiwhinā',
        'Thaa' => 'Tāna',
        'Thai' => 'Tai',
        'Tibt' => 'Tipete',
        'Vaii' => 'Wai',
        'Yiii' => 'Ei',
        'Zmth' => 'Reo Tohu Pāngarau',
        'Zsye' => 'Emohi',
        'Zsym' => 'Tohu',
        'Zxxx' => 'Tuhikore',
        'Zyyy' => 'Komona',
    ],
];

==> symfony_6.4.5+dfsg.orig.tar.xz: symfony-6.4.5/src/Symfony/Component/Intl/Resources/data/scripts/mi.php <==
<?php

return [
    'Names' => [
        'Adlm' => 'Atarama',
        'Arab' => 'Arapika',
        'Aran' => 'Nātarika',
        'Armn' => 'Āmeniana',
        'Beng' => 'Pāngara',
        'Bopo' => 'Papamawha',
        'Brai' => 'Tuhi Matapō',
        'Cakm' => 'Tiakamā',
        'Cans' => 'Ngā Kūoro o ngā Iwi Taketake o Kānata kua paiheretia',
        'Cher' => 'Terokī',
        'Cyrl' => 'Hīririki',
        'Deva' => 'Tewhangāngari',
        'Ethi' => 'Etiopika',
        'Geor' => 'Hōriana',
        'Grek' => 'Kariki',
        'Gujr' => 'Kutarāti',
        'Guru' => 'Kūmuki',
        'Hanb' => 'Hana me te Papamawha',
        'Hang' => 'Hāngū',
        'Hani' => 'Hana',
        'Hans' => 'Māmā',
        'Hant' => 'Tuku iho',
        'Hebr' => 'Hīperu',
        'Hira' => 'Hirakana',
        'Hrkt' => 'Kūoro Hapanihi',
        'Jamo' => 'Hamo',
        'Jpan' => 'Hapanihi',
        'Kana' => 'Katakana',
        'Khmr' => 'Kimēra',
        'Knda' => 'Kanāra',
        'Kore' => 'Kōreana',
        'Laoo' => 'Rao',
        'Latn' => 'Rātini',
        'Mlym' => 'Maraiārama',
        'Mong' => 'Mongōria',
        'Mtei' => 'Meitei Maeke',
        'Mymr' => 'Mienemā',
        'Nkoo' => 'Unukō',
        'Olck' => 'Ōtiki',
        'Orya' => 'Otia',
        'Rohg' => 'Hāniwhi',
        'Sinh' => 'Hināra',
        'Sund' => 'Hunanihi',
        'Syrc' => 'Hīriaka',
        'Taml' => 'Tamiera',
        'Telu' => 'Teruku',
        'Tfng' => 'Tiwhinā',
        'Thaa' => 'Tāna',
        'Thai' => 'Tai',
        'Tibt' => 'Tipete',
        'Vaii' => 'Wai',
        'Yiii' => 'Eī',
        'Zmth' => 'Reo Tohu Pāngarau',
        'Zsye' => 'Emohi',
        'Zsym' => 'Tohu',
        'Zxxx' => 'Tuhikore',
        'Zyyy' => 'Komona',
    ],
];
